@@ -345,6 +345,8 @@ public:
         icon_edit_copy,
         icon_edit_paste,
         icon_edit_delete,
+        icon_edit_undo,
+        icon_edit_redo,
 
         icon_edit_end, // nothing beyond this point
     };
@@ -625,7 +627,7 @@ public:
     void start();
     void stop();
 
-#ifdef Q_OS_WIN
+#if defined Q_OS_WIN && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     void setProgressBar(QWinTaskbarProgress *progressbar);
     QWinTaskbarProgress *progressBar();
 #else
@@ -641,7 +643,7 @@ private:
     QSharedPointer<DkGlobalProgress> inst;
     bool showProgress;
 
-#ifdef Q_OS_WIN
+#if defined Q_OS_WIN && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     QWinTaskbarProgress *mProgress = 0;
 #else
     QProgressDialog *mProgress = 0;
