@@ -328,7 +328,7 @@ bool DkBasicLoader::loadGeneral(const QString &filePath, QSharedPointer<QByteArr
     // - if the suffix has no match in Qt, this will fail
     // - if the suffix is empty, plugins will check the file header
     LoaderResult result;
-    if (loader.isNull() && qtFormats.contains(suffix) || suffix.isEmpty()) {
+    if (loader.isNull() && (qtFormats.contains(suffix) || suffix.isEmpty())) {
         result = loadQt(mFile, ba, suffix);
         if (result.ok) {
             loader = "qt";
@@ -402,6 +402,10 @@ bool DkBasicLoader::loadGeneral(const QString &filePath, QSharedPointer<QByteArr
         indexPages(mFile, ba);
     mPageIdxDirty = false;
 
+    // copy QImage::text() data to DkMetaData
+    if (!loader.isNull())
+        mMetaData->setQtValues(img);
+
     int rotation = DkMetaDataT::or_invalid;
     bool mirrored = false;
 
@@ -2187,7 +2191,8 @@ bool DkRawLoader::load(const QSharedPointer<QByteArray> ba)
 
     try {
         // open the buffer
-        LibRaw iProcessor;
+        auto libRawPtr = std::make_unique<LibRaw>(); // huge stack allocation crashes MacOS
+        auto &iProcessor = *libRawPtr;
 
         iProcessor.imgdata.params.use_camera_wb = 1;
         iProcessor.imgdata.params.output_color = 1;
