@@ -27,6 +27,7 @@
 
 #include "DkSettings.h"
 #include "DkUtils.h"
+#include "DkVersion.h"
 
 #pragma warning(push, 0) // no warnings from includes - begin
 #include <cassert>
@@ -39,6 +40,7 @@
 #include <QDir>
 #include <QFileInfo>
 #include <QImageReader>
+#include <QMimeDatabase>
 #include <QRandomGenerator>
 #include <QScreen>
 #include <QStandardItem>
@@ -167,6 +169,8 @@ void DkSettings::initFileFilters()
         app_p.saveFilters.append("AV1 Image File Format (*.avif)");
     if (qtFormats.contains("qoi"))
         app_p.saveFilters.append("Quite OK Image Format (*.qoi)");
+    if (qtFormats.contains("hej2"))
+        app_p.saveFilters.append("JPEG 2000 image encapsulated in HEIF (*.hej2)");
 
 #ifdef Q_OS_WIN
     if (qtFormats.contains("ico"))
@@ -195,6 +199,8 @@ void DkSettings::initFileFilters()
         app_p.openFilters.append("AVIF image sequence (*.avifs)");
     if (qtFormats.contains("apng"))
         app_p.openFilters.append("Animated Portable Network Graphics (*.apng)");
+    if (qtFormats.contains("avci"))
+        app_p.openFilters.append("AVC-encoded image encapsulated in HEIF (*.avci)");
 
 #ifndef Q_OS_WIN
     if (qtFormats.contains("ico"))
@@ -1137,6 +1143,62 @@ void DkFileFilterHandling::registerFileAssociations()
     qInfo() << "files registered...";
 }
 
+void DkFileFilterHandling::printFormats(QTextStream &out, const QString &outFormat)
+{
+    QMimeDatabase db;
+    QStringList fileFilters = nmc::DkSettingsManager::param().app().fileFilters;
+    std::sort(fileFilters.begin(), fileFilters.end());
+
+    QVector<QStringList> rows; // collect all data on each extension
+    QStringList mimeNames; // unique names
+    for (QString ext : fileFilters) { // "*.jpg"
+        ext = ext.mid(2); // "jpg"
+        const auto mimeTypes = db.mimeTypesForFileName("file." + ext);
+
+        QStringList columns(ext);
+        columns.append(mimeTypes.count() ? mimeTypes[0].comment() : "n/a");
+        // TODO: nomacs filter name
+        // TODO: add column if type is writeable
+        for (const QMimeType &mime : mimeTypes) {
+            auto name = mime.name(); // "image/jpeg"
+            columns.append(name);
+            if (!mimeNames.contains(name))
+                mimeNames.append(name);
+            // in practice is always <2 so just skip the others
+        }
+        rows.append(columns);
+    }
+    std::sort(mimeNames.begin(), mimeNames.end());
+
+    if (outFormat == "plist") {
+        // filetype metadata for macos Info.plist, used by "make filetypes"
+        auto indent = QString(' ').repeated(8); // matches Info.plist.in
+
+        out << "<!-- begin list-formats -->\n";
+        out << indent << "<!-- " << nmc::revisionString << ", " << QSysInfo().prettyProductName() << " -->\n";
+        out << indent << "<key>CFBundleTypeExtensions</key>\n";
+        out << indent << "<array>\n";
+        for (auto &row : rows)
+            out << indent << "  <string>" << row[0] << "</string>\n";
+        out << indent << "</array>\n";
+        out << indent << "<key>CFBundleTypeMIMETypes</key>\n";
+        out << indent << "<array>\n";
+        for (auto &mime : mimeNames)
+            out << indent << "  <string>" << mime << "</string>\n";
+        out << indent << "</array>\n";
+        out << indent << "<!-- end list-formats -->";
+
+    } else if (outFormat == "xdg") {
+        // for .desktop file
+        out << "MimeType=" << mimeNames.join(';');
+    } else if (outFormat == "csv") {
+        for (auto &row : rows)
+            out << row.join(',') << "\n";
+    } else {
+        qCritical() << "invalid output format (see --help for usage)";
+    }
+}
+
 void DkFileFilterHandling::registerNomacs(bool showDefaultApps)
 {
 #ifdef Q_OS_WIN
