@@ -87,7 +87,9 @@
 #include <QShortcut>
 #include <QSplashScreen>
 #include <QStringBuilder>
+#include <QSysInfo>
 #include <QTimer>
+#include <QUrlQuery>
 #include <QVector2D>
 #include <QtGlobal>
 #include <qmath.h>
@@ -179,7 +181,6 @@ void DkNoMacs::init()
 {
     // assign icon -> in windows the 32px version
     QString iconPath = ":/nomacs/img/nomacs.svg";
-    loadStyleSheet();
 
     QIcon nmcIcon = QIcon(iconPath);
     setObjectName("DkNoMacs");
@@ -210,6 +211,9 @@ void DkNoMacs::init()
 
     // connections to the image loader
     connect(getTabWidget(), &DkCentralWidget::imageUpdatedSignal, this, QOverload<QSharedPointer<DkImageContainerT>>::of(&DkNoMacs::setWindowTitle));
+    connect(getTabWidget(), &DkCentralWidget::thumbViewLoadedSignal, this, [this](const QString &path) {
+        setWindowTitle(path);
+    });
 
     DkActionManager::instance().enableMovieActions(false);
 
@@ -232,12 +236,6 @@ void DkNoMacs::createStatusBar()
     setStatusBar(DkStatusBarManager::instance().statusbar());
 }
 
-void DkNoMacs::loadStyleSheet()
-{
-    DkThemeManager tm;
-    tm.applyTheme();
-}
-
 void DkNoMacs::createMenu()
 {
     setMenuBar(mMenu);
@@ -254,8 +252,12 @@ void DkNoMacs::createMenu()
         mMenu->addMenu(am.syncMenu());
 
 #ifdef WITH_PLUGINS
-    // plugin menu
+    // empty menu, populated on first click
     mPluginsMenu = mMenu->addMenu(tr("Pl&ugins"));
+
+    // we need a dummy action or else QPA might hide the menu (Mac)
+    mPluginsMenu->addAction(new QAction("<Plugins Loaded Here>"));
+
     am.pluginActionManager()->setMenu(mPluginsMenu);
 #endif // WITH_PLUGINS
 
@@ -275,7 +277,7 @@ void DkNoMacs::createActions()
     connect(am.action(DkActionManager::menu_file_quick_launch), &QAction::triggered, this, &DkNoMacs::openQuickLaunch);
     connect(am.action(DkActionManager::menu_file_open_list), &QAction::triggered, this, &DkNoMacs::openFileList);
     connect(am.action(DkActionManager::menu_file_save_list), &QAction::triggered, this, &DkNoMacs::saveFileList);
-    connect(am.action(DkActionManager::menu_file_rename), &QAction::triggered, this, &DkNoMacs::renameFile);
+    connect(am.action(DkActionManager::menu_file_rename), &QAction::triggered, getTabWidget(), &DkCentralWidget::renameFile);
     connect(am.action(DkActionManager::menu_file_goto), &QAction::triggered, this, &DkNoMacs::goTo);
 
     connect(am.action(DkActionManager::menu_file_show_recent), &QAction::triggered, getTabWidget(), &DkCentralWidget::showRecentFiles);
@@ -612,6 +614,8 @@ void DkNoMacs::toggleFullScreen()
 
 void DkNoMacs::enterFullScreen()
 {
+    setUpdatesEnabled(false);
+
     int appMode = DkSettingsManager::param().app().currentAppMode;
     appMode = DkSettings::fullscreenMode(appMode);
     DkSettingsManager::param().app().currentAppMode = appMode;
@@ -626,20 +630,25 @@ void DkNoMacs::enterFullScreen()
             << "windowState:" << windowState();
 
     mWasMaximized = isMaximized();
+
+    if (getTabWidget()->getViewPort())
+        getTabWidget()->getViewPort()->setFullScreen(true);
+
+    setUpdatesEnabled(true);
+
     showFullScreen();
 
     qInfo() << "after enter fullscreen appMode:" << appMode << "geometry:" << geometry() << "normalGeometry:" << normalGeometry()
             << "windowState:" << windowState();
 
-    if (getTabWidget()->getViewPort())
-        getTabWidget()->getViewPort()->setFullScreen(true);
-
     update();
 }
 
 void DkNoMacs::exitFullScreen()
 {
     if (isFullScreen()) {
+        setUpdatesEnabled(false);
+
         int appMode = DkSettingsManager::param().app().currentAppMode;
         if (!DkSettings::modeIsFullscreen(appMode))
             qWarning() << "expected fullscreen app mode, but got" << appMode;
@@ -657,6 +666,14 @@ void DkNoMacs::exitFullScreen()
         DkToolBarManager::inst().restore();
         restoreDocks();
 
+        if (getTabWidget())
+            getTabWidget()->showTabs(true);
+
+        if (getTabWidget()->getViewPort())
+            getTabWidget()->getViewPort()->setFullScreen(false);
+
+        setUpdatesEnabled(true);
+
         qInfo() << "before exit fullscreen appMode:" << appMode << "geometry:" << geometry() << "normalGeometry:" << normalGeometry()
                 << "windowState:" << windowState();
 
@@ -668,14 +685,8 @@ void DkNoMacs::exitFullScreen()
         qInfo() << "after exit fullscreen appMode:" << appMode << "geometry:" << geometry() << "normalGeometry:" << normalGeometry()
                 << "windowState:" << windowState();
 
-        if (getTabWidget())
-            getTabWidget()->showTabs(true);
-
         update(); // if no resize is triggered, the viewport won't change its color
     }
-
-    if (getTabWidget()->getViewPort())
-        getTabWidget()->getViewPort()->setFullScreen(false);
 }
 
 void DkNoMacs::toggleDocks(bool hide)
@@ -878,7 +889,7 @@ void DkNoMacs::lockWindow(bool lock)
 
     qDebug() << "locking: " << lock;
 
-    if (lock) {
+    if (lock && windowOpacity() < 1.0f) {
         // setAttribute(Qt::WA_TransparentForMouseEvents);
         HWND hwnd = (HWND)winId(); // get handle of the widget
         LONG styles = GetWindowLong(hwnd, GWL_EXSTYLE);
@@ -993,6 +1004,7 @@ void DkNoMacs::showExplorer(bool show, bool saveSettings)
         });
         connect(mExplorer, &DkExplorer::openDir, getTabWidget(), &DkCentralWidget::loadDirToTab);
         connect(getTabWidget(), &DkCentralWidget::imageUpdatedSignal, mExplorer, &DkExplorer::setCurrentImage);
+        connect(getTabWidget(), &DkCentralWidget::thumbViewLoadedSignal, mExplorer, &DkExplorer::setCurrentPath);
     }
 
     mExplorer->setVisible(show, saveSettings);
@@ -1019,6 +1031,9 @@ void DkNoMacs::showMetaDataDock(bool show, bool saveSettings)
         addDockWidget(mMetaDataDock->getDockLocationSettings(Qt::RightDockWidgetArea), mMetaDataDock);
 
         connect(getTabWidget(), &DkCentralWidget::imageUpdatedSignal, mMetaDataDock, &DkMetaDataDock::setImage);
+        connect(getTabWidget(), &DkCentralWidget::thumbViewLoadedSignal, mMetaDataDock, [this]() {
+            mMetaDataDock->setImage(nullptr);
+        });
     }
 
     mMetaDataDock->setVisible(show, saveSettings);
@@ -1318,77 +1333,6 @@ void DkNoMacs::loadFile(const QString &filePath)
         getTabWidget()->loadFile(filePath, false);
 }
 
-// TODO: move this
-void DkNoMacs::renameFile()
-{
-    // TODO:ref move!
-    QString filePath = getTabWidget()->getCurrentFilePath();
-    QFileInfo file(filePath);
-
-    if (!file.absoluteDir().exists()) {
-        getTabWidget()->setInfo(tr("Sorry, the directory: %1 does not exist\n").arg(file.absolutePath()));
-        return;
-    }
-    if (file.exists() && !file.isWritable()) {
-        getTabWidget()->setInfo(tr("Sorry, I can't write to the fileInfo: %1").arg(file.fileName()));
-        return;
-    }
-
-    QString fileName = file.fileName();
-    int dotIdx = fileName.lastIndexOf(".");
-    QString baseName = dotIdx != -1 ? fileName.left(dotIdx) : fileName;
-
-    bool ok = false;
-    QString newFileName = QInputDialog::getText(this, baseName, tr("Rename:"), QLineEdit::Normal, baseName, &ok);
-
-    if (ok && !newFileName.isEmpty() && newFileName != baseName) {
-        if (!file.suffix().isEmpty())
-            newFileName.append("." + file.suffix());
-
-        qDebug() << "renaming: " << file.fileName() << " -> " << newFileName;
-        QFileInfo renamedFile = QFileInfo(file.absoluteDir(), newFileName);
-
-        // overwrite file?
-        // the second comparison is important for windows (case insensitive filenames)
-        if (renamedFile.exists() && renamedFile.absoluteFilePath().compare(file.absoluteFilePath(), Qt::CaseInsensitive) != 0) {
-            QMessageBox infoDialog(this);
-            infoDialog.setWindowTitle(tr("Question"));
-            infoDialog.setText(tr("The fileInfo: %1  already exists.\n Do you want to replace it?").arg(newFileName));
-            infoDialog.setIcon(QMessageBox::Question);
-            infoDialog.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
-            infoDialog.setDefaultButton(QMessageBox::No);
-            infoDialog.show();
-            int choice = infoDialog.exec();
-
-            if (choice == QMessageBox::Yes) {
-                QFile oldFile(renamedFile.absoluteFilePath());
-                bool removed = oldFile.remove();
-
-                // tell user that deleting went wrong, and stop the renaming
-                if (!removed) {
-                    getTabWidget()->setInfo(tr("Sorry, I can't delete: %1").arg(file.fileName()));
-                    return;
-                }
-            } else
-                return; // cancel renaming
-        }
-
-        if (getTabWidget()->getViewPort())
-            getTabWidget()->getViewPort()->unloadImage();
-
-        QFile newFile(file.absoluteFilePath());
-        bool renamed = newFile.rename(renamedFile.absoluteFilePath());
-
-        // tell user that deleting went wrong, and stop the renaming
-        if (!renamed)
-            getTabWidget()->setInfo(tr("Sorry, I can't rename: %1").arg(file.fileName()));
-        else if (DkSettingsManager::param().resources().loadSavedImage == DkSettings::ls_load)
-            getTabWidget()->loadFile(renamedFile.absoluteFilePath());
-        else if (getTabWidget()->getViewPort())
-            getTabWidget()->getViewPort()->loadNextFileFast();
-    }
-}
-
 void DkNoMacs::find(bool filterAction)
 {
     if (!getTabWidget()->getCurrentImageLoader())
@@ -1397,7 +1341,6 @@ void DkNoMacs::find(bool filterAction)
     if (filterAction) {
         int db = (QObject::sender() == DkActionManager::instance().action(DkActionManager::menu_tools_filter)) ? DkSearchDialog::filter_button
                                                                                                                : DkSearchDialog::find_button;
-
         qDebug() << "default button: " << db;
         DkSearchDialog *searchDialog = new DkSearchDialog(this);
         searchDialog->setDefaultButton(db);
@@ -1530,9 +1473,8 @@ void DkNoMacs::computeThumbsBatch()
 
 void DkNoMacs::aboutDialog()
 {
-    DkSplashScreen *spScreen = new DkSplashScreen(this);
-    spScreen->exec();
-    spScreen->deleteLater();
+    DkSplashScreen splash;
+    splash.exec();
 }
 
 void DkNoMacs::openDocumentation()
@@ -1543,8 +1485,31 @@ void DkNoMacs::openDocumentation()
 
 void DkNoMacs::bugReport()
 {
-    QString url = "https://github.com/nomacs/nomacs/issues/new";
-    QDesktopServices::openUrl(QUrl(url));
+    QString info = R"(
+**Description**
+A clear and concise description.
+
+**Steps to Reproduce**
+List the sequence of actions leading to the bug.
+
+**Expected Behavior**
+A clear and concise description of what you expected to happen.
+
+**Screenshot / Screencast / Images**
+Add screen recording or example files to help illustrate the problem.
+
+**Additional context**
+Add any other context about the problem.
+
+**System Info**)";
+    info += '\n' + DkUtils::getBuildInfo().replace("\n\n", "");
+
+    QUrlQuery query;
+    query.addQueryItem("body", info);
+    QUrl url("https://github.com/nomacs/nomacs/issues/new");
+    url.setQuery(query);
+
+    QDesktopServices::openUrl(url);
 }
 
 void DkNoMacs::cleanSettings()
@@ -1814,21 +1779,27 @@ void DkNoMacs::setWindowTitle(const QString &filePath, const QSize &size, bool e
     // TODO: move!
     DkStatusBar *bar = DkStatusBarManager::instance().statusbar();
 
-    if (((vp && !vp->getController()->getFileInfoLabel()->isVisible())
-         || !DkSettingsManager::param().slideShow().display.testBit(DkSettings::display_creation_date))
-        && getTabWidget()->getCurrentImage()) {
-        // create statusbar info
-        QSharedPointer<DkMetaDataT> metaData = getTabWidget()->getCurrentImage()->getMetaData();
-        QString dateString = metaData->getExifValue("DateTimeOriginal");
-        dateString = DkUtils::convertDateString(dateString, fInfo);
-        bar->setMessage(dateString, DkStatusBar::status_time_info);
-    } else
+    if (fInfo.isDir()) {
         bar->setMessage("", DkStatusBar::status_time_info); // hide label
-
-    if (fInfo.exists())
-        bar->setMessage(DkUtils::readableByte((float)fInfo.size()), DkStatusBar::status_filesize_info);
-    else
         bar->setMessage("", DkStatusBar::status_filesize_info);
+        bar->setMessage("", DkStatusBar::status_filenumber_info);
+    } else {
+        if (((vp && !vp->getController()->getFileInfoLabel()->isVisible())
+             || !DkSettingsManager::param().slideShow().display.testBit(DkSettings::display_creation_date))
+            && getTabWidget()->getCurrentImage()) {
+            // create statusbar info
+            QSharedPointer<DkMetaDataT> metaData = getTabWidget()->getCurrentImage()->getMetaData();
+            QString dateString = metaData->getExifValue("DateTimeOriginal");
+            dateString = DkUtils::convertDateString(dateString, fInfo);
+            bar->setMessage(dateString, DkStatusBar::status_time_info);
+        } else
+            bar->setMessage("", DkStatusBar::status_time_info); // hide label
+
+        if (fInfo.exists())
+            bar->setMessage(DkUtils::readableByte(fInfo.size()), DkStatusBar::status_filesize_info);
+        else
+            bar->setMessage("", DkStatusBar::status_filesize_info);
+    }
 }
 
 void DkNoMacs::settingsChanged()
@@ -2107,6 +2078,20 @@ DkNoMacsIpl::DkNoMacsIpl(QWidget *parent, Qt::WindowFlags flags)
     setMouseTracking(true); // receive mouse event everytime
 }
 
+void DkNoMacsIpl::paintEvent(QPaintEvent *event)
+{
+    // prevent visual glitch where initial fullscreen window is filled
+    // with normal window bg color. Once the viewport comes up it takes over
+    // drawing the background and dock widgets get the default bg color
+    bool hasViewPort = getTabWidget() && getTabWidget()->hasViewPort();
+    if (isFullScreen() && !hasViewPort) {
+        QColor bgColor = nmc::DkSettingsManager::param().slideShow().backgroundColor;
+        QPainter painter(this);
+        painter.fillRect(rect(), bgColor);
+    } else
+        QMainWindow::paintEvent(event);
+}
+
 // FramelessNoMacs --------------------------------------------------------------------
 DkNoMacsFrameless::DkNoMacsFrameless(QWidget *parent, Qt::WindowFlags flags)
     : DkNoMacs(parent, flags)
@@ -2166,6 +2151,21 @@ void DkNoMacsFrameless::createContextMenu()
     am.contextMenu()->addAction(am.action(DkActionManager::menu_file_exit));
 }
 
+void DkNoMacsFrameless::paintEvent(QPaintEvent *event)
+{
+    // paint everything except the central/transparent area
+    const QRegion mask = QRegion(event->rect()).subtracted(centralWidget()->geometry());
+
+    if (!mask.isEmpty()) {
+        QPainter painter(this);
+        const QColor &bgColor = DkSettingsManager::param().display().bgColor;
+        for (auto it = mask.begin(); it != mask.end(); ++it)
+            painter.fillRect(*it, bgColor);
+    }
+
+    DkNoMacs::paintEvent(event);
+}
+
 void DkNoMacsFrameless::chooseMonitor(bool force)
 {
     QScreen *oldScreen = qApp->screenAt(geometry().topLeft());
