@@ -333,11 +333,11 @@ void DkThumbsSaver::loadNext()
     if (mStop)
         return;
 
-    int force = (mForceSave) ? DkThumbNail::force_save_thumb : DkThumbNail::save_thumb;
+    auto mode = mForceSave ? DkThumbNail::write_exif_always : DkThumbNail::write_exif;
 
     for (int idx = 0; idx < mImages.size(); idx++) {
         connect(mImages.at(idx)->getThumb().data(), &DkThumbNailT::thumbLoadedSignal, this, &DkThumbsSaver::thumbLoaded);
-        mImages.at(idx)->getThumb()->fetchThumb(force);
+        mImages.at(idx)->getThumb()->fetchThumb(mode);
     }
 }
 
@@ -408,8 +408,6 @@ DkBrowseExplorer::DkBrowseExplorer(const QString &title, QWidget *parent, Qt::Wi
 {
     createLayout();
     readSettings();
-
-    connect(mRootPathBrowseButton, &QPushButton::clicked, this, &DkBrowseExplorer::browseClicked);
 }
 
 DkBrowseExplorer::~DkBrowseExplorer()
@@ -425,6 +423,11 @@ void DkBrowseExplorer::browseClicked()
         setRootPath(root);
 }
 
+void DkBrowseExplorer::scrollToCurrentClicked()
+{
+    mFileTree->scrollTo(mFileTree->currentIndex());
+}
+
 void DkBrowseExplorer::setRootPath(const QString &root)
 {
     mRootPath = root;
@@ -439,10 +442,19 @@ void DkBrowseExplorer::createLayout()
     QWidget *rootPathWidget = new QWidget(this);
     QHBoxLayout *rpLayout = new QHBoxLayout(rootPathWidget);
     mRootPathLabel = new DkElidedLabel(rootPathWidget, "");
-    mRootPathBrowseButton = new QPushButton(tr("Browse"));
+
+    auto browseButton = new QPushButton(tr("Browse"));
+    connect(browseButton, &QPushButton::clicked, this, &DkBrowseExplorer::browseClicked);
+
+    auto scrollButton = new QToolButton();
+    scrollButton->setIcon(DkImage::loadIcon(":/nomacs/img/scroll-to-current.svg"));
+    scrollButton->setToolTip(tr("Scroll to current file"));
+    connect(scrollButton, &QPushButton::clicked, this, &DkBrowseExplorer::scrollToCurrentClicked);
+
     rpLayout->setContentsMargins(4, 2, 2, 2);
     rpLayout->addWidget(mRootPathLabel, 1);
-    rpLayout->addWidget(mRootPathBrowseButton);
+    rpLayout->addWidget(browseButton);
+    rpLayout->addWidget(scrollButton);
 
     mLayout->insertWidget(0, rootPathWidget);
 }
@@ -1847,7 +1859,6 @@ void DkEditableRect::drawGuide(QPainter *painter, const QPolygonF &p, int paintM
     painter->setPen(cPen);
 
     // vertical
-    DkVector lp = p[1] - p[0]; // parallel to drawing
     DkVector l9 = p[3] - p[0]; // perpendicular to drawing
 
     int nLines = (paintMode == rule_of_thirds) ? 3 : qRound(l9.norm() / 20.0f);
@@ -1865,7 +1876,6 @@ void DkEditableRect::drawGuide(QPainter *painter, const QPolygonF &p, int paintM
     }
 
     // horizontal
-    lp = p[3] - p[0]; // parallel to drawing
     l9 = p[1] - p[0]; // perpendicular to drawing
 
     nLines = (paintMode == rule_of_thirds) ? 3 : qRound(l9.norm() / 20);
