@@ -326,7 +326,6 @@ public slots:
     void animateOpacityUp();
     void animateOpacityDown();
 
-protected slots:
     void updateFile(int idx);
 
 signals:
@@ -453,6 +452,7 @@ public:
 
 public slots:
     void browseClicked();
+    void scrollToCurrentClicked();
     void setRootPath(const QString &root);
 
 protected:
@@ -461,7 +461,6 @@ protected:
     void writeSettings() override;
 
     QString mRootPath;
-    QPushButton *mRootPathBrowseButton;
     DkElidedLabel *mRootPathLabel;
 };
 
@@ -533,8 +532,8 @@ public slots:
     virtual void setVisible(bool visible, bool autoHide = false);
 
     void updateZoom(double zoomLevel);
-    void on_sbZoom_valueChanged(double zoomLevel);
-    void on_slZoom_valueChanged(int zoomLevel);
+    void onSbZoomValueChanged(double zoomLevel);
+    void onSlZoomValueChanged(int zoomLevel);
 
 protected:
     void createLayout();
@@ -714,7 +713,7 @@ public:
     void setPainted(bool isPainted);
 
 public slots:
-    void on_toggleStats_triggered(bool show);
+    void onToggleStatsTriggered(bool show);
 
 protected:
     virtual void mousePressEvent(QMouseEvent *event) override;
@@ -810,7 +809,7 @@ public:
     DkDirectoryChooser(const QString &dirPath = "", QWidget *parent = 0);
 
 public slots:
-    void on_dirButton_clicked();
+    void onDirButtonClicked();
 
 signals:
     void directoryChanged(const QString &dirPath) const;
@@ -835,7 +834,7 @@ public:
         if (time)
             timer->start(time);
 
-        connect(timer, SIGNAL(timeout()), this, SLOT(sendInfo()));
+        connect(timer, &QTimer::timeout, this, &DkDelayedInfo::sendInfo);
     }
 
     virtual ~DkDelayedInfo()
